@@ -2,7 +2,7 @@
 #-------------------------------------------------------------------------
 # Module: Gbook
 # Author: Jos (josvd@live.nl)
-# Version: 1.1
+# Version: 2.0.2
 #
 #-------------------------------------------------------------------------
 # CMS - CMS Made Simple is (c) 2009 by Ted Kulp (wishy@cmsmadesimple.org)
@@ -38,12 +38,12 @@ class Gbook extends CMSModule
 
 	function GetFriendlyName()
 	{
-		return $this->GetPreference('custom_modulename', $this->Lang('friendlyname'));
+		return $this->Lang('friendlyname');
 	}
 
 	function GetVersion()
 	{
-		return '1.1';
+		return '2.0.2';
 	}
 
 	function GetHelp()
@@ -103,7 +103,7 @@ class Gbook extends CMSModule
 
 	function MinimumCMSVersion()
 	{
-		return "1.10";
+		return "1.11";
 	}
 
 	function InitializeFrontend()
