@@ -14,7 +14,7 @@ if (!isset($gCms)) exit;
 $alias = empty($params['alias']) ? $this->GetPreference('defaultgbook') : $params['alias'];
 $gbooks = Gbook_utils::GetGbooks($alias);
 $gbook = $gbooks[0];
-$smarty->assign_by_ref('gbook_props', $gbook);
+$smarty->assign('gbook_props', $gbook);
 
 
 // pagination
@@ -25,27 +25,21 @@ $start = (($params['gbpage'] - 1) * $gbook['entries_page']) + 1;
 
 // get template
 $template = $this->GetPreference('default_summary_template');
-if ( !empty($params['template']) && $params['template'] != $template )
+if ( !empty($params['template']) )
 {
 	$template = 'summary_tpl_' . $params['template'];
-	$linkparams['template'] = $template;
+	$linkparams['template'] = $params['template'];
 }
 
 
+
 // get cache
 $cache_id = '|gb'.md5($gbook['gbook_id'].'-'.$params['gbpage'].'-'.$gbook['entries'].'-'.$gbook['entries_page']);
-$compile_id = '';
-global $CMS_VERSION;
-if( $CMS_VERSION >= '1.11' && $smarty->isCached($this->GetDatabaseResource($template),$cache_id,$compile_id) ) 
-{
-	// Display cached template
-	echo $smarty->fetch($this->GetDatabaseResource($template),$cache_id,$compile_id);
-}
-else
+if( !$smarty->isCached($this->GetDatabaseResource($template),$cache_id) ) 
 {
 	// get gbook entries
 	$entries = Gbook_utils::GetEntries($gbook['gbook_id'], $start, $gbook['entries_page']);
-	$smarty->assign_by_ref('gbook_entries', $entries);
+	$smarty->assign('gbook_entries', $entries);
 
 
 	// pagination links
@@ -56,17 +50,12 @@ else
 		$linkparams['gbpage'] = $i;
 		$pagelinks[$i] = $this->CreateFrontendLink($id, $returnid, 'default', '', $linkparams, '', true, true, '', false); //, $prettyurl . $i . '/' . $returnid);
 	}
-	$smarty->assign_by_ref('gbook_pagelinks', $pagelinks);
+	$smarty->assign('gbook_pagelinks', $pagelinks);
 	$smarty->assign('gbook_currentpage', $params['gbpage']);
 	$smarty->assign('gbook_entrieslabel', $this->Lang('entries'));
-	
-	if( $CMS_VERSION >= '1.11' )
-	{
-		echo $smarty->fetch($this->GetDatabaseResource($template),$cache_id,$compile_id);
-	}
-	else
-	{
-		echo $this->ProcessTemplateFromDatabase($template);	
-	}
 }
+
+// Display template
+echo $smarty->fetch($this->GetDatabaseResource($template),$cache_id);
+
 ?>
\ No newline at end of file
