@@ -10,8 +10,6 @@
 
 if (!isset($gCms)) exit;
 
-global $CMS_VERSION;
-
 // handle the page to go to after cancel or submit.
 $dest_page = $returnid;
 $redirect = $this->GetPreference('form_redirect');
@@ -49,7 +47,7 @@ if ( empty($gbook) )
 }
 
 // token
-$token = $this->GetPreference('gbook_token', array(0=>0));
+$token = $this->GetPreference('gbook_token', 's:0:"";');
 $token = unserialize($token);
 $tokentimestamp = ceil(time()/60/5);
 if ( empty($token[$tokentimestamp]) ) 
@@ -112,7 +110,7 @@ if( $_SERVER['REQUEST_METHOD'] == 'POST' && isset($params['submit']) )
 					}
 					$cmsmailer->SetSubject($gbook['admin_notification_subject']);
 					$cmsmailer->IsHTML(false);
-					$body = $CMS_VERSION < '1.11' ? $this->ProcessTemplateFromData($gbook['admin_notification_message']) : $smarty->fetch('string:'.$gbook['admin_notification_message']);
+					$body = $smarty->fetch('string:'.$gbook['admin_notification_message']);
 					$cmsmailer->SetBody($body);
 					$cmsmailer->Send();
 					$cmsmailer->ClearAddresses();
@@ -121,14 +119,7 @@ if( $_SERVER['REQUEST_METHOD'] == 'POST' && isset($params['submit']) )
 			
 			// display submission response
 			$response = ($spamrate <= $this->GetPreference('max_spamrate_active', 0.6)) ? 'submission_response' : 'submission_response_spam';
-			if ( $CMS_VERSION < '1.11' )
-			{
-				echo $this->ProcessTemplateFromData($gbook[$response]);					
-			}
-			else
-			{
-				echo $smarty->display('string:'.$gbook[$response]);
-			}
+			echo $smarty->display('string:'.$gbook[$response]);
 		}
 		elseif ( is_array($addentry) )
 		{
@@ -239,11 +230,8 @@ if ( $showform )
 		$template = 'form_tpl_' . $params['template'];
 	}
 		
-	if ( $CMS_VERSION >= '1.11' )
-	{
-		// clear cache for this template
-		$smarty->clearCache($this->GetDatabaseResource($template));
-	}
+	// clear cache for this template
+	$smarty->clearCache($this->GetDatabaseResource($template));
 	echo $this->ProcessTemplateFromDatabase($template);
 }
 
