@@ -3,6 +3,7 @@ $lang['friendlyname'] = 'Gastenboeken';
 $lang['moddescription'] = 'Cre&euml;er en beheer gastenboeken en ontvang feedback van uw website bezoekers';
 $lang['description'] = 'Ontvang feedback van uw website bezoekers';
 $lang['postinstall'] = 'De Gbook module is succesvol ge&iuml;nstalleerd. Zie de admin Content sectie: &#039;%s&#039;.';
+$lang['spam'] = 'Spam';
 $lang['areyousure'] = 'Weet u zeker dat u dit wilt verwijderen?';
 $lang['areyousuremulti'] = 'Weet u zeker dat u deze bulk-actie wilt uitvoeren?';
 $lang['gbooks'] = 'Gastenboeken';
@@ -24,11 +25,11 @@ $lang['admin_notification_message'] = 'Admin notificatie email bericht';
 $lang['required_fields'] = 'Vereiste velden op de Frontend';
 $lang['import_csv'] = 'Importeer berichten via csv';
 $lang['csv_format'] = 'csv formaat: &quot;author&quot;[string];&quot;email&quot;[string];&quot;title&quot;[string];&quot;message&quot;[string];&quot;ip&quot;[string];&quot;create_date&quot;[date/time:yyyy-mm-dd hh:mm:ss]';
-$lang['smileys'] = 'Smileys ';
-$lang['smiley'] = 'Smiley ';
+$lang['smileys'] = 'Smileys';
+$lang['smiley'] = 'Smiley';
 $lang['addsmiley'] = 'Voeg Smiley toe';
-$lang['id'] = 'ID ';
-$lang['spamrate'] = 'Spam Rating ';
+$lang['id'] = 'ID';
+$lang['spamrate'] = 'Spam Rating';
 $lang['created'] = 'Gemaakt';
 $lang['modified'] = 'Bewerkt';
 $lang['itemadded'] = 'Bericht is toegevoegd';
@@ -46,7 +47,11 @@ $lang['default_summary_template'] = 'Standaard lijst sjabloon';
 $lang['default_detail_template'] = 'Standaard detail sjabloon';
 $lang['resetdefault'] = 'Laad/reset standaard sjabloon';
 $lang['resetwarning'] = 'Weet u zeker dat u de sjabloon code wilt resetten naar de standaard?';
-$lang['send_notifications_to'] = 'Emailadres waar notificaties van nieuwe berichten naartoe gestuurd worden';
+$lang['title_custom_modulename'] = 'Eigen Modulenaam';
+$lang['help_custom_modulename'] = 'U kunt hier de Modulenaam naar eigen wens aanpassen. Het zal gebruikt worden als titel op de module beheerpagina en als menu tekst.';
+$lang['title_admin_section'] = 'Admin Sectie';
+$lang['help_admin_section'] = 'Kies de Admin Sectie (van het Admin topmenu) waar deze module moet worden getoond.';
+$lang['send_notifications_to'] = 'E-mailadres waar notificaties van nieuwe berichten naartoe gestuurd worden';
 $lang['max_spamrate_active'] = 'Maximale spamrating waarbij berichten automatisch op actief gezet worden na inzenden';
 $lang['max_spamrate_active_help'] = 'tussen 0 en 1, standaard 0.6. Hoe lager deze waarde, hoe meer berichten niet standaard actief zijn.';
 $lang['max_spamrate_notify'] = 'Maximale spamrating waarbij een notificatie email naar de admin wordt verstuurd';
@@ -57,7 +62,7 @@ $lang['badwords'] = 'Maskeer ondeugende woorden (komma gescheiden)';
 $lang['optionsupdated'] = 'De opties zijn succesvol bijgewerkt.';
 $lang['entries'] = 'Berichten';
 $lang['name'] = 'Naam';
-$lang['email'] = 'Email ';
+$lang['email'] = 'E-mail';
 $lang['title'] = 'Titel';
 $lang['message'] = 'Bericht';
 $lang['notify'] = 'Stuur mij een email bij nieuwe berichten';
@@ -65,7 +70,7 @@ $lang['fe_submit'] = 'Verstuur';
 $lang['validation_errors'] = 'Geef a.u.b. een correcte waarde voor de gemarkeerde velden en verstuur opnieuw.';
 $lang['double_post'] = '<p>Bedankt voor uw bericht. Uw bericht was al toegevoegd aan ons gastenboek.</p>';
 $lang['not_allowed_to_post_twice'] = '<p>Sorry. Vanwege spam-beveiliging is het niet mogelijk om twee berichten na elkaar te plaatsen. Excuses voor dit ongemak.</p>
-<p>Probeert u het a.u.b. later nog een keer, of stuur ons een email zodat wij namens u het bericht aan ons gastenboek kunnen toevoegen.</p>';
+<p>Probeert u het a.u.b. later nog een keer, of stuur ons een e-mail zodat wij namens u het bericht aan ons gastenboek kunnen toevoegen.</p>';
 $lang['submission_response_cnt'] = '<p>Bedankt voor uw bericht. Uw bericht is toegevoegd aan ons gastenboek.</p>';
 $lang['submission_response_spam_cnt'] = '<p>Bedankt voor uw bericht.</p>
 <p>Uw bericht lijkt echter spam te bevatten, daarom wordt het niet direct in ons gastenboek getoond, maar is eerst een controle vereist.</p>
@@ -119,11 +124,9 @@ Users must belong to a group with the &#039;Gbook: Modify&#039; permission to be
 </ul>
 
 <h3>Feedback</h3>
-<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="http://forum.cmsmadesimple.org/viewtopic.php?f=7&amp;t=64460">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>
-';
-$lang['utmz'] = '57867837.1345118961.1699.18.utmcsr=cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['utma'] = '57867837.1815583785146351600.1249721294.1355688860.1355769343.1709';
-$lang['qca'] = 'P0-802263609-1268423862699';
-$lang['utmb'] = '57867837.71.10.1355829120';
-$lang['utmc'] = '57867837';
+<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="http://forum.cmsmadesimple.org/viewtopic.php?f=7&amp;t=64460">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>';
+$lang['utma'] = '156861353.1834246644.1386548232.1386548232.1386548232.1';
+$lang['utmz'] = '156861353.1386548232.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
+$lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
