@@ -77,10 +77,11 @@ class Gbook_utils
 	}
 	
 	
-	public static function GetEntries($gbook_id, $start = 1, $number = 20, $filter = true) {
+	public static function GetEntries($gbook_id, $start = 1, $number = 20, $filter = 'active') {
 		$start = ($start < 1) ? 0 : $start - 1;
 		$output = array();
 
+		$mod = cms_utils::get_module('Gbook');
 		$db = cmsms()->GetDB();
 		$query = "SELECT
 								e.*, g.allow_smilies
@@ -91,9 +92,19 @@ class Gbook_utils
 								e.gbook_id = g.gbook_id
 								AND e.gbook_id = ?
 								";
-		if ( $filter === true )
+		switch ( $filter )
 		{
-			$query .= "AND e.active = 1";
+			case 'active':
+				$query .= "AND e.active = 1";
+				break;
+			case 'inactive':
+				$query .= "AND e.active = 0";
+				break;
+			case 'spam':
+				self::UpdateSpamrate($gbook_id, $mod->GetPreference('update_spamrate_' . $gbook_id));
+				$mod->SetPreference('update_spamrate_' . $gbook_id, 0);
+				$query .= "AND e.spamrate >= " . $db->Qmagic($mod->GetPreference('max_spamrate_active', 0.5) * 100);
+				break;
 		}
 		$query .= "
 							ORDER BY
@@ -115,7 +126,6 @@ class Gbook_utils
 				{
 					$onerow->message = self::replace_smileys($onerow->message);
 				}
-				$mod = cms_utils::get_module('Gbook');
 				$badwords = $mod->GetPreference('badwords', '');
 				if ( !empty($badwords) )
 				{
@@ -215,7 +225,7 @@ class Gbook_utils
 		// check for double posts
 		$ip = cms_utils::get_real_ip();
 		$lastentry = self::GetEntries($gbook_id, 1, 1, false);
-		if ( $message == $lastentry[0]->rawmessage ) 
+		if ( !empty($lastentry) && $message == $lastentry[0]->rawmessage ) 
 		{
 			$errors[] = $gbook_id;
 			return array('double post' => $errors);
@@ -285,7 +295,7 @@ class Gbook_utils
 						$mod->SendEvent('Gbook_entry_added', $params);
 
 						//Update search index
-						$search = cms_utils::get_module('Search');
+						$search = cms_utils::get_search_module();
 						if ( $search != false )
 						{
 							$search->AddWords($mod->GetName(), $insert_id, 'entry', $params['title'] . ' ' . $params['message']);
@@ -351,7 +361,7 @@ class Gbook_utils
 			$mod->SendEvent('Gbook_entry_edited', $params);
 
 			//Update search index
-			$search = cms_utils::get_module('Search');
+			$search = cms_utils::get_search_module();;
 			if ( $search != false )
 			{
 				if ( $active == 1 )
@@ -378,22 +388,89 @@ class Gbook_utils
 		$db = cmsms()->GetDB();
 		$query = "DELETE FROM " . cms_db_prefix() . "module_gbook_entries WHERE entry_id = ?";
 		$result = $db->Execute($query, array($entry_id));
+		if ( $result )
+		{
+			$mod = cms_utils::get_module('Gbook');
+			$params['entry_id'] = $entry_id;
+			$params['gbook_id'] = $gbook_id;
+			$mod->SendEvent('Gbook_entry_deleted', $params);
+			
+			//Update search index
+			$search = cms_utils::get_search_module();
+			if ( $search != false )
+			{
+				$search->DeleteWords($mod->GetName(), $entry_id, 'entry');
+			}
+			return true;
+		}
+		else
+		{
+			echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+			exit();
+		}
+	}
+
+	
+	public static function UpdateSpamrate($gbook_id, $updateall) {
+		$db = cmsms()->GetDB();
+		$query = "SELECT
+								entry_id, title, message
+							FROM
+								" . cms_db_prefix() . "module_gbook_entries
+							WHERE
+								gbook_id = ?
+								";
+		if ( $updateall == 0 )
+		{
+			$query .= "AND spamrate IS NULL";
+		}
+		$query .= "
+							ORDER BY
+								create_date DESC";
+		$result = $db->Execute($query, array($gbook_id)) ;
+		if ( $result && $result->RecordCount() > 0 )
+		{
+		  while ( $row=$result->FetchRow() )
+		  {
+				$spamrate = self::b8_exec('Classify', $row['title'] . ' ' . $row['message']);
+				$query = "UPDATE " . cms_db_prefix() . "module_gbook_entries SET spamrate = ? WHERE entry_id = ?";
+				$db->Execute($query, array($spamrate * 100, $row['entry_id']));
+		  }
+		}
+		if ( !$result )
+		{
+			echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
+			echo '<pre>' . $query . '</pre>';
+			exit();
+		}
+		return true;
+	}
+
+	
+	public static function UpdateAllSpamrates() {
+		$mod = cms_utils::get_module('Gbook');
+		$db = cmsms()->GetDB();
+		$query = "SELECT
+								gbook_id
+							FROM
+								" . cms_db_prefix() . "module_gbook";
+		$result = $db->Execute($query);
+		if ( $result && $result->RecordCount() > 0 )
+		{
+		  while ( $row=$result->FetchRow() )
+		  {
+				$mod->SetPreference('update_spamrate_' . $row['gbook_id'], 1);
+		  }
+		}
 		if ( !$result )
 		{
 			echo 'ERROR: ' . __LINE__ . ' » ' . mysql_error();
 			exit();
 		}
-		
-		//Update search index
-		$mod = cms_utils::get_module('Gbook');
-		$search = cms_utils::get_module('Search');
-		if ( $search != false )
-		{
-			$search->DeleteWords($mod->GetName(), $entry_id, 'entry');
-		}
 		return true;
-	}
 
+	}
+	
 	
 	public static function GetSmileys($filter = true) {
 		$smileyscache = cms_utils::get_app_data('gbook_smileys_'.$filter);
@@ -494,7 +571,7 @@ class Gbook_utils
 		$config = cmsms()->GetConfig();
 		
 		$config_b8 = array(
-			'storage' => 'mysql'
+			'storage' => 'mysqli'
 		);
 
 		$config_storage = array(
@@ -523,7 +600,7 @@ class Gbook_utils
 			$b8 = new b8($config_b8, $config_storage, $config_lexer, $config_degenerator);
 		}
 		catch(Exception $e) {
-			echo "<b>example:</b> Could not initialize b8.<br />\n";
+			echo "<b>Could not initialize b8.</b><br />\n";
 			echo "<b>Error message:</b> ", $e->getMessage();
 			echo "\n\n</div>\n\n</body>\n\n</html>";
 			exit();
